@@ -398,6 +398,11 @@ function suite.okay_nested_subdefine()
    assert(result, msg)
 end
 
+function suite.okay_negated_subdefine()
+   local result, msg = compiler.compile(comp_context, "subdefine3")
+   assert(result, msg)
+end
+
 local count_ok = 0
 for _, testname in ipairs(testnames) do
 --   print("Run: " .. testname)
